#include <windows.h>
#include <memory.h>
#include <commdlg.h>
#include "global.h"
#include "print.h"

//****************************************************************************
// Function: GetDefaultPrinterDC
//
// Purpose: Gets a printer DC to the default printer.
//
// Parameters:
//    hWnd - handle to the top level app window.
//
// Returns : None
//
// History:  Date       Author        Reason
//           5/15/93                   Created
//****************************************************************************

HDC GetDefaultPrinterDC(HWND hWnd)
{
	PRINTDLG pd;
		
	_fmemset((LPPRINTDLG)&pd, 0, sizeof(PRINTDLG));
	pd.lStructSize = sizeof(PRINTDLG);
	pd.hwndOwner = hWnd;
	pd.Flags = PD_RETURNDEFAULT | PD_RETURNDC;
	
	PrintDlg(&pd);
	
    if (pd.hDevMode != NULL)
       GlobalFree(pd.hDevMode);
    if (pd.hDevNames != NULL)
       GlobalFree(pd.hDevNames);
       
	return pd.hDC;
}

//****************************************************************************
// Function: PrintHandler
//
// Purpose: Prints the document.
//
// Parameters:
//    hWnd - handle to the top level app window.
//    hPrnDC - DC to the printer.
//
// Returns : None
//
// History:  Date       Author        Reason
//           5/15/93                   Created
//****************************************************************************
      
void PrintHandler(HWND hWnd, HDC hPrnDC)			
{
	FARPROC lpAbortProc;
	DOCINFO di;
	UINT uPageNum = 0;
	
	lpAbortProc = MakeProcInstance(PrintAbortProc, ghInst);

	/* Define the abort function */
	SetAbortProc(hPrnDC, lpAbortProc);
		
	di.cbSize = sizeof(DOCINFO);
	di.lpszDocName = (LPCSTR)"MULFON document";
	di.lpszOutput = NULL;
        
	if (SP_ERROR == StartDoc(hPrnDC, (LPDOCINFO)&di))
		MessageBox(hWnd, "Unable to start print job", NULL, MB_OK | MB_ICONHAND);
	else
	{
		for (uPageNum = 0; uPageNum < guNumPages; uPageNum++)
		{	
			StartPage(hPrnDC);
			SelectObject(hPrnDC, (HGDIOBJ)ghFont);
			RepaintClient(NULL, hPrnDC, glpPages[uPageNum].uFirstLine, 
			              glpPages[uPageNum].uLastLine);			
			EndPage(hPrnDC);
		}	
		EndDoc(hPrnDC);

		SelectObject(hPrnDC, (HGDIOBJ)ghFont);
	}		
		
	FreeProcInstance(lpAbortProc);
}

/****************************************************************
 * PrintAbortProc() is the abort procedure used by Windows when *
 * printing.                                                    *
 * Return TRUE indicates to keep printing                       *
 ****************************************************************/

BOOL FAR PASCAL PrintAbortProc(HDC hdcPrn, short nCode)
{
   MSG msg;

   while (PeekMessage(&msg, NULL, 0, 0, PM_REMOVE))
   {
      TranslateMessage(&msg);
      DispatchMessage(&msg);
   }
   return TRUE;
}
